{% extends "base.html" %}
{% block title %}Workflow - Not found{% endblock %}
{% block title_header %}Workflow not found{% endblock %}
{% block content %}
<div class="ui-widget">
    <div class="ui-state-highlight ui-corner-all" style="padding: .3em .7em;">
        <p>
            <span class="ui-icon ui-icon-info"
                style="float: left; margin-right: .3em;"></span> <strong>Info:</strong>
            We were unable to locate information for the requested workflow. Try again later. If the problem persists, contact the administrator.
        </p>
    </div>
</div>
{% endblock %}
