{% extends "base.html" %}
{% block title %}Help{% endblock %}
{% block javascript_init %}
{% endblock %}
{% block navigation_bar %}
<li class="active">Info</li>
{% endblock %}
{% block title_header %}Contact Us{% endblock %}
{% block content %}
<section class="row">
    <div class="col-xs-12">
        <p>To contact us for technical support, send us an Email at
            <span class="pe-7s-mail fa-lg"> </span> <a href="mailto:pegasus-users@isi.edu">pegasus-users@isi.edu</a>.
        </p>
    </div>
</section>
{% endblock %}
