{% extends "base-error.html" %}
{% block title %}Database - Migration/Operational Error{% endblock %}
{% block title_header %}Database Migration Error{% endblock %}
{% block navigation_bar %}-{% endblock %}
{% block content %}
<section class="row">
    <div class="col-xs-12">
        <h3>Possible Reasons</h3>
        <hr>
        <ul>
            <li>
                Master Database (v{{ e.db_compatible_version }}) is not compatible with the current version of Pegasus (v{{ e.pegasus_compatible_version }}).
            </li>
            <li>
                STAMPEDE Database (v{{ e.db_compatible_version }}) is not compatible with the current version of Pegasus (v{{ e.pegasus_compatible_version }}).
            </li>
        </ul>
        <h3>Solution(s)</h3>
        <hr>
        <ul>
            {% if e.db_version < e.pegasus_version %}
            <li>Please execute pegasus-db-admin update on the database you are trying to access.</li>
            {% endif %}
            {% if e.db_version > e.pegasus_version %}
            <li>The database was created using a newer version of pegasus. Restart Pegasus dashboard from the new Pegasus version</li>
            {% endif %}
        </ul>
    </div>
</section>
{% endblock %}
